@@ -10,7 +10,7 @@ import sys
 import tempfile
 sys.path.insert(0, os.path.join(os.path.dirname(__file__), '../'))
 
-from titlecase import titlecase, set_small_word_list
+from titlecase import titlecase, set_small_word_list, create_wordlist_filter_from_file
 
 
 # (executed by `test_input_output` below)
@@ -31,6 +31,10 @@ TEST_DATA = (
         "dance with me/let’s face the music and dance",
         "Dance With Me/Let’s Face the Music and Dance"
     ),
+    (
+        "a-b end-to-end two-not-three/three-by-four/five-and",
+        "A-B End-to-End Two-Not-Three/Three-by-Four/Five-And"
+    ),
     (
         "34th 3rd 2nd",
         "34th 3rd 2nd"
@@ -247,6 +251,14 @@ TEST_DATA = (
         "o'melveny/o'doyle o'Melveny/o'doyle O'melveny/o'doyle o'melveny/o'Doyle o'melveny/O'doyle",
         "O'Melveny/O'Doyle O'Melveny/O'Doyle O'Melveny/O'Doyle O'Melveny/O'Doyle O'Melveny/O'Doyle",
     ),
+    # These 'Mc' cases aim to ensure more consistent/predictable behavior.
+    # The examples here are somewhat contrived, and are subject to change
+    # if there is a compelling argument for updating their behavior.
+    # See https://github.com/ppannuto/python-titlecase/issues/64
+    (
+        "mccay-mcbut-mcdo mcdonalds/mcby",
+        "McCay-McBut-McDo McDonalds/McBy"
+    ),
     (
         "oblon, spivak, mcclelland, maier & neustadt",
         "Oblon, Spivak, McClelland, Maier & Neustadt",
@@ -291,6 +303,11 @@ TEST_DATA = (
         "ýæ ñø",
         "Ýæ Ñø",
     ),
+    # https://github.com/ppannuto/python-titlecase/pull/67
+    (
+        "Mr mr Mrs Ms Mss Dr dr , Mr. and Mrs. Person",
+        "Mr Mr Mrs Ms MSS Dr Dr , Mr. And Mrs. Person",
+    ),
 )
 
 
@@ -363,7 +380,7 @@ def test_custom_abbreviations():
         # Without a wordlist, this will do the "wrong" thing for the context
         assert titlecase('SENDING UDP PACKETS OVER PPPOE WORKS GREAT') == 'Sending Udp Packets Over Pppoe Works Great'
         # A wordlist can provide custom acronyms
-        assert titlecase('sending UDP packets over PPPoE works great', wordlist_file=f.name) == 'Sending UDP Packets Over PPPoE Works Great'
+        assert titlecase('sending UDP packets over PPPoE works great', callback=create_wordlist_filter_from_file(f.name)) == 'Sending UDP Packets Over PPPoE Works Great'
 
 
 if __name__ == "__main__":
